const state = {
    journals: [],
    periods: [],
    paymentTerms: [],
    selectedJournal: null,
    selectedPaymentTerm: null
}

const getters = {
    journals(state) {
        return state.journals
    },
    periods(state) {
        return state.periods
    },
    paymentTerms(state) {
        return state.paymentTerms
    },
    selectedJournal(state) {
        return state.selectedJournal
    },
    selectedPaymentTerm(state) {
        return state.selectedPaymentTerm
    }
}

const mutations = {
    setJournals(state, payload) {
        state.journals = payload
    },
    setPeriods(state, payload) {
        state.periods = payload
    },
    setPaymentTerms(state, payload) {
        state.paymentTerms = payload
    },
    setSelectedJournal(state, payload) {
        state.selectedJournal = payload
    },
    setSelectedPaymentTerm(state, payload) {
        state.selectedPaymentTerm = payload
    }
}

const actions = {
    fetchJournals({ commit, dispatch }) {
        return new Promise((resolve, reject) => {
            let AccountJournal = new openerp.web.Model('account.journal')

            AccountJournal.call('get_journals', {
                context: new openerp.web.CompoundContext()
            }).then(response => {
                commit('setJournals', response)
                dispatch('loaded', 'journals')

                resolve()
            }).fail(error => {
                console.log(error)
                reject(error)
            })
        })
    },
    fetchPeriods({ commit, dispatch }) {
        return new Promise((resolve, reject) => {
            let AccountPeriod = new openerp.web.Model('account.period')

            AccountPeriod.call('get_periods', {
                context: new openerp.web.CompoundContext()
            }).then(response => {
                commit('setPeriods', response)
                dispatch('loaded', 'periods')

                resolve()
            }).fail(error => {
                console.log(error)
                reject(error)
            })
        })
    },
    fetchPaymentTerms({ commit, dispatch }) {
        return new Promise((resolve, reject) => {
            let AccountPaymentTerm = new openerp.web.Model('account.payment.term')

            AccountPaymentTerm.call('get_account_payment_terms', {
                context: new openerp.web.CompoundContext()
            }).then(response => {
                commit('setPaymentTerms', response)
                dispatch('loaded', 'paymentTerms')

                resolve()
            }).fail(error => {
                console.log(error)
                reject(error)
            })
        })
    }
}

export default {
    state,
    getters,
    mutations,
    actions
}